@@ -56,7 +56,7 @@ def _parse_args(startlogs):
     misc.add_argument(
         "-v", "--version",
         action="version",
-        version='GSuite_Sync v0.2.0\n{}'.format(sys.version))
+        version='GSuite_Sync v0.2.1\n{}'.format(sys.version))
     misc.add_argument(
         '-s', "--setup",
         help="Create GSuite API token file from OAuth client credentials file",
@@ -504,7 +504,8 @@ def setup():
           "quickstart/python")
     print("    Enable the directory API and download the "
           "credentials.json file")
-    scope = ['https://www.googleapis.com/auth/admin.directory.device.chromeos']
+    scope = ['https://www.googleapis.com/auth/admin.directory.device.chromeos',
+             'https://www.googleapis.com/auth/admin.directory.user']
     credentials_file = input("File Path of the credentials.json file: ")
     flow = InstalledAppFlow.from_client_secrets_file(credentials_file, scope)
     print("Finding page for token creation")
@@ -520,8 +521,9 @@ def setup():
     creds_data = json.dumps(creds_data, indent=4)
     print("Token Data:\n{}".format(creds_data))
     token_file = input("File path to create new token file: ")
-    with open(token_file, "wb") as new_cred_file:
-        pickle.dump(creds, new_cred_file)
+    with open(token_file, "w") as new_cred_file:
+        # pickle.dump(creds, new_cred_file)
+        new_cred_file.write(creds_data)
     print("Done!")
 
 
